==> django-simpletask2-0.0.8.tar.gz: django-simpletask2-0.0.8/setup.py <==
# -*- coding: utf-8 -*-
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = [x.strip() for x in fobj.readlines() if x.strip()]


setup(
    name="django-simpletask2",
    version="0.0.8",
    description="A simple asynchronous task manager based on the Django framework. All business logic written in a custom task data model. Tasks are triggered by a Redis queue.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Chang TianQun",
    author_email="changtianqun@zencore.cn",
    maintainer="Chang TianQun",
    maintainer_email="changtianqun@zencore.cn",
    license="MIT",
    license_files=("LICENSE",),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django-simpletask2"],
    install_requires=requires,
    packages=find_packages(
        ".",
        exclude=(
            "django_simpletask2_demo",
            "django_simpletask2_example",
            "django_simpletask2_example.migrations",
        ),
    ),
    zip_safe=False,
    include_package_data=True,
    entry_points={
        "console_scripts": [
            "django-simpletask2-server = django_simpletask2_server:controller",
        ]
    },
)

==> django-simpletask2-0.1.9.tar.gz: django-simpletask2-0.1.9/setup.py <==
# -*- coding: utf-8 -*-
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = [x.strip() for x in fobj.readlines() if x.strip()]


setup(
    name="django-simpletask2",
    version="0.1.9",
    description="A simple asynchronous task manager based on the Django framework. All business logic written in a custom task data model. Tasks are triggered by a Redis queue.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Chang TianQun",
    author_email="changtianqun@zencore.cn",
    maintainer="Chang TianQun",
    maintainer_email="changtianqun@zencore.cn",
    license="MIT",
    license_files=("LICENSE",),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=[
        "django-simpletask2",
    ],
    install_requires=requires,
    packages=find_packages(
        ".",
        exclude=(
            "django_simpletask2_demo",
            "django_simpletask2_example",
            "django_simpletask2_example.migrations",
        ),
    ),
    zip_safe=False,
    include_package_data=True,
)
